# Tanjun

A flexible command framework designed to extend Hikari.

# Installation

You can install Tanjun from PyPI using the following command in any Python 3.9 or above environment.

```
python -m pip install -U hikari-tanjun
```

# Quick Usage

For usage see the the [documentation](https://tanjun.cursed.solutions/)
and the [examples](https://github.com/FasterSpeeding/Tanjun/tree/master/examples)
or [tutorials and articles](https://patchwork.systems/programming/hikari-discord-bot/index.html).

# Support

Hikari's support guild has a dedicated Tanjun help channel which can accessed using this
[invite](https://discord.gg/Jx4cNGG).

# Contributing

Before contributing you should read through the
[contributing guidelines](https://github.com/FasterSpeeding/Tanjun/blob/master/CONTRIBUTING.md) and
the [code of conduct](https://github.com/FasterSpeeding/Tanjun/blob/master/CODE_OF_CONDUCT.md)
